Package: rmcorr
Title: Repeated Measures Correlation
Version: 0.7.0
Authors@R: c(
    person("Jonathan Z.", "Bakdash", email = "jbakdash@gmail.com", role = "aut",
      comment = c(ORCID = "0000-0002-1409-4779")
    ),
    person("Laura R.", "Marusich", email = "lmarusich@gmail.com", role = c("aut", "cre"),
      comment = c(ORCID = "0000-0002-3524-6110")
    )
  )
Description: Compute the repeated measures correlation, a statistical technique
    for determining the overall within-individual relationship among paired measures
    assessed on two or more occasions, first introduced by Bland and Altman (1995).
    Includes functions for diagnostics, p-value, effect size with confidence
    interval including optional bootstrapping, as well as graphing. Also includes
    several example datasets. For more details, see the web documentation 
    <https://lmarusich.github.io/rmcorr/index.html> and the 
    original paper: Bakdash and Marusich (2017) <doi:10.3389/fpsyg.2017.00456>.
Depends: R (>= 4.1.0)
License: GPL-2
LazyData: true
Imports: stats, grDevices, graphics, psych, RColorBrewer
RoxygenNote: 7.3.2
Encoding: UTF-8
Suggests: knitr, rmarkdown, ggplot2, plotrix, lme4, merTools, pwr,
        AICcmodavg, pals, testthat (>= 3.0.0), vdiffr, corrplot, cocor,
        covr, ggExtra, gglm, dplyr, esc, patchwork
VignetteBuilder: knitr
Config/testthat/edition: 3
URL: https://github.com/lmarusich/rmcorr
BugReports: https://github.com/lmarusich/rmcorr/issues
NeedsCompilation: no
Packaged: 2024-07-26 19:28:08 UTC; DoD_Admin
Author: Jonathan Z. Bakdash [aut] (<https://orcid.org/0000-0002-1409-4779>),
  Laura R. Marusich [aut, cre] (<https://orcid.org/0000-0002-3524-6110>)
Maintainer: Laura R. Marusich <lmarusich@gmail.com>
Repository: CRAN
Date/Publication: 2024-07-26 23:10:05 UTC
Built: R 4.6.0; ; 2026-04-26 01:46:40 UTC; unix
